@@ -10,7 +10,7 @@ class CameraImpulseRunner(ImpulseRunner):
         self.closed = True
         self.labels = []
         self.dim = (0, 0)
-        self.videoCapture = None
+        self.videoCapture = cv2.VideoCapture()
 
     def init(self):
         model_info = super(CameraImpulseRunner, self).init()
@@ -23,7 +23,6 @@ class CameraImpulseRunner(ImpulseRunner):
 
         self.dim = (width, height)
         self.labels = model_info['model_parameters']['labels']
-        self.videoCapture = cv2.VideoCapture(0)
         return model_info
 
     def __enter__(self):
@@ -31,13 +30,16 @@ class CameraImpulseRunner(ImpulseRunner):
         return self
 
     def __exit__(self, type, value, traceback):
+        self.videoCapture.release()
         self.closed = True
 
     def classify(self):
+        self.videoCapture.open(0)
         while not self.closed:
             # Capture frame-by-frame
             ret, brg = self.videoCapture.read()
-            resizedImg = cv2.resize(brg, self.dim, interpolation = cv2.INTER_AREA)
-            features = np.array(resizedImg).flatten().tolist()
-            res = runner.classify(features)
-            yield res, brg
+            if ret:
+                resizedImg = cv2.resize(brg, self.dim, interpolation = cv2.INTER_AREA)
+                features = np.array(resizedImg).flatten().tolist()
+                res = super(CameraImpulseRunner, self).classify(features)
+                yield res, brg
